/*
 * MaterialBase.hpp
 *
 *  Created on: Nov 12, 2014
 *      Author: nano
 */

#ifndef MATERIALBASE_HPP_
#define MATERIALBASE_HPP_

#include "../common/SimulationItemBase.hpp"
#include <memory>

namespace phoxonics {
namespace core {

class MaterialBase {
public:
    MaterialBase();
    virtual ~MaterialBase();

    // electric properties
    double eps { 0.0 };        // absolute permittivity
    double eps_r { 0.0 };      // relative permittivity (dielectric constant)

    // magnetic properties
    double mu { 0.0 };         // permeability
    double mu_r { 0.0 };       // relative permittivity

    // Electrical resistivity, represented by the Greek letter (rho), is a measure of how
    // strongly a material opposes the flow of electric current. The lower the resistivity,
    // the more readily the material permits the flow of electric charge.
    double rho { 0.0 };

    // Electrical conductivity is the reciprocal quantity of resistivity. Conductivity is a
    // measure of how well a material conducts an electric current. Electric conductivity may
    // be represented by the Greek letter (sigma), (kappa), or (gamma).
    double sigma { 0.0 };
};

} /* namespace core */
} /* namespace phoxonics */

#endif /* MATERIALBASE_HPP_ */
